==> ec2-1.4.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/Subnet.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Represents a new VPC subnet resource.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.3 (build 1b1062d)", date = "2019-08-14T08:19:47.011Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.Subnet")
public class Subnet extends software.amazon.awscdk.core.Resource implements software.amazon.awscdk.services.ec2.ISubnet {
    protected Subnet(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public Subnet(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.ec2.SubnetProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.ec2.ISubnet fromSubnetAttributes(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.ec2.SubnetAttributes attrs) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.Subnet.class, "fromSubnetAttributes", software.amazon.awscdk.services.ec2.ISubnet.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(attrs, "attrs is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static java.lang.Boolean isVpcSubnet(@javax.annotation.Nullable final java.lang.Object x) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.Subnet.class, "isVpcSubnet", java.lang.Boolean.class, new Object[] { x });
    }

    /**
     * Create a default route that points to a passed IGW, with a dependency on the IGW's attachment to the VPC.
     * 
     * @param gatewayId the logical ID (ref) of the gateway attached to your VPC.
     * @param gatewayAttachment the gateway attachment construct to be added as a dependency.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void addDefaultInternetRoute(final java.lang.String gatewayId, final software.amazon.awscdk.core.IDependable gatewayAttachment) {
        this.jsiiCall("addDefaultInternetRoute", Void.class, new Object[] { java.util.Objects.requireNonNull(gatewayId, "gatewayId is required"), java.util.Objects.requireNonNull(gatewayAttachment, "gatewayAttachment is required") });
    }

    /**
     * Adds an entry to this subnets route table that points to the passed NATGatwayId.
     * 
     * @param natGatewayId The ID of the NAT gateway.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void addDefaultNatRoute(final java.lang.String natGatewayId) {
        this.jsiiCall("addDefaultNatRoute", Void.class, new Object[] { java.util.Objects.requireNonNull(natGatewayId, "natGatewayId is required") });
    }

    /**
     * The Availability Zone the subnet is located in.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getAvailabilityZone() {
        return this.jsiiGet("availabilityZone", java.lang.String.class);
    }

    /**
     * Parts of this VPC subnet.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.util.List<software.amazon.awscdk.core.IDependable> getDependencyElements() {
        return this.jsiiGet("dependencyElements", java.util.List.class);
    }

    /**
     * Dependable that can be depended upon to force internet connectivity established on the VPC.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public software.amazon.awscdk.core.IDependable getInternetConnectivityEstablished() {
        return this.jsiiGet("internetConnectivityEstablished", software.amazon.awscdk.core.IDependable.class);
    }

    /**
     * The routeTableId attached to this subnet.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public software.amazon.awscdk.services.ec2.IRouteTable getRouteTable() {
        return this.jsiiGet("routeTable", software.amazon.awscdk.services.ec2.IRouteTable.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getSubnetAvailabilityZone() {
        return this.jsiiGet("subnetAvailabilityZone", java.lang.String.class);
    }

    /**
     * The subnetId for this particular subnet.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getSubnetId() {
        return this.jsiiGet("subnetId", java.lang.String.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.util.List<java.lang.String> getSubnetIpv6CidrBlocks() {
        return this.jsiiGet("subnetIpv6CidrBlocks", java.util.List.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getSubnetNetworkAclAssociationId() {
        return this.jsiiGet("subnetNetworkAclAssociationId", java.lang.String.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getSubnetVpcId() {
        return this.jsiiGet("subnetVpcId", java.lang.String.class);
    }
}

==> ec2-1.5.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/Subnet.java <==
package software.amazon.awscdk.services.ec2;

/**
 * Represents a new VPC subnet resource.
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.15.1 (build ceff2ca)", date = "2019-08-21T10:50:03.225Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.Subnet")
public class Subnet extends software.amazon.awscdk.core.Resource implements software.amazon.awscdk.services.ec2.ISubnet {

    protected Subnet(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Subnet(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }
    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public Subnet(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.ec2.SubnetProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        this.setObjRef(software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") }));
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static software.amazon.awscdk.services.ec2.ISubnet fromSubnetAttributes(final software.amazon.awscdk.core.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.ec2.SubnetAttributes attrs) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.Subnet.class, "fromSubnetAttributes", software.amazon.awscdk.services.ec2.ISubnet.class, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(attrs, "attrs is required") });
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static java.lang.Boolean isVpcSubnet(final java.lang.Object x) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.ec2.Subnet.class, "isVpcSubnet", java.lang.Boolean.class, new Object[] { x });
    }

    /**
     * Create a default route that points to a passed IGW, with a dependency on the IGW's attachment to the VPC.
     * 
     * @param gatewayId the logical ID (ref) of the gateway attached to your VPC.
     * @param gatewayAttachment the gateway attachment construct to be added as a dependency.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void addDefaultInternetRoute(final java.lang.String gatewayId, final software.amazon.awscdk.core.IDependable gatewayAttachment) {
        this.jsiiCall("addDefaultInternetRoute", Void.class, new Object[] { java.util.Objects.requireNonNull(gatewayId, "gatewayId is required"), java.util.Objects.requireNonNull(gatewayAttachment, "gatewayAttachment is required") });
    }

    /**
     * Adds an entry to this subnets route table that points to the passed NATGatwayId.
     * 
     * @param natGatewayId The ID of the NAT gateway.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public void addDefaultNatRoute(final java.lang.String natGatewayId) {
        this.jsiiCall("addDefaultNatRoute", Void.class, new Object[] { java.util.Objects.requireNonNull(natGatewayId, "natGatewayId is required") });
    }

    /**
     * The Availability Zone the subnet is located in.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getAvailabilityZone() {
        return this.jsiiGet("availabilityZone", java.lang.String.class);
    }

    /**
     * Parts of this VPC subnet.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.util.List<software.amazon.awscdk.core.IDependable> getDependencyElements() {
        return this.jsiiGet("dependencyElements", java.util.List.class);
    }

    /**
     * Dependable that can be depended upon to force internet connectivity established on the VPC.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public software.amazon.awscdk.core.IDependable getInternetConnectivityEstablished() {
        return this.jsiiGet("internetConnectivityEstablished", software.amazon.awscdk.core.IDependable.class);
    }

    /**
     * The routeTableId attached to this subnet.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public software.amazon.awscdk.services.ec2.IRouteTable getRouteTable() {
        return this.jsiiGet("routeTable", software.amazon.awscdk.services.ec2.IRouteTable.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getSubnetAvailabilityZone() {
        return this.jsiiGet("subnetAvailabilityZone", java.lang.String.class);
    }

    /**
     * The subnetId for this particular subnet.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getSubnetId() {
        return this.jsiiGet("subnetId", java.lang.String.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.util.List<java.lang.String> getSubnetIpv6CidrBlocks() {
        return this.jsiiGet("subnetIpv6CidrBlocks", java.util.List.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getSubnetNetworkAclAssociationId() {
        return this.jsiiGet("subnetNetworkAclAssociationId", java.lang.String.class);
    }

    /**
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public java.lang.String getSubnetVpcId() {
        return this.jsiiGet("subnetVpcId", java.lang.String.class);
    }
}
